%% author
% Travis Burgers
% Raven Industries
% September 2020
% travis.burgers@ravenind.com

%% Instructions
% Load parsed data into workspace
% load('R4045andRoGatordata.mat')

% This script calls CalculateBoomLevelingMetrics.m, which must be in this workspace
 
% Select group/waterway100 to analyze
% group = 1         JDR4045 straightaway
% group = 2         JDR4045 terraces
% group = 3         RoGator straightaway
% group = 4         RoGator terraces
% waterway100 = 0   straightaway
% waterway100 = 1   waterwayway (only with group = 1 or 3)

group = 3;
waterway100 = 1;

% output: analysis metrics for all runs in group are given in analysismetricsoutput
% output: see plots/results definition and setup section to activate/inactiviate graphical outputs

%% file names and sets
if group == 1 %JD straight
    fname = {'BoomTracStraight81', 'BoomTracStraight82', 'BoomTracStraight83',...
        'BoomTracStraight121', 'BoomTracStraight122', 'BoomTracStraight123', ...
        'BoomTracStraight161', 'BoomTracStraight162', 'BoomTracStraight163', ...
        'XRTStraight81', 'XRTStraight82', 'XRTStraight83', ...
        'XRTStraight121', 'XRTStraight122', 'XRTStraight123', ...
        'XRTStraight161', 'XRTStraight162', 'XRTStraight163'};
    name = {'Bs81', 'Bs82', 'Bs83', 'Bs121', 'Bs122', 'Bs123', ...
        'Bs161', 'Bs162', 'Bs163', ...
        'Xs81', 'Xs82', 'Xs83', 'Xs121', 'Xs122', 'Xs123', ...
        'Xs161', 'Xs162', 'Xs163'};
elseif group == 2 %JD terraces
    fname = {'BoomTrachill61', 'BoomTrachill62', 'BoomTrachill63',...
        'BoomTrachill81', 'BoomTrachill82', 'BoomTrachill83', ...
        'BoomTrachill101', 'BoomTrachill102', 'BoomTrachill103', ...
        'XRThill61', 'XRThill62', 'XRThill63', ...
        'XRThill81', 'XRThill82', 'XRThill83', ...
        'XRThill101', 'XRThill102', 'XRThill103', ...
        'XRThill121', 'XRThill122', 'XRThill123'};  
    name = {'Bh61', 'Bh62', 'Bh63', 'Bh81', 'Bh82', 'Bh83', ...
        'Bh101', 'Bh102', 'Bh103', ...
        'Xh61', 'Xh62', 'Xh63', 'Xh81', 'Xh82', 'Xh83', ...
        'Xh101', 'Xh102', 'Xh103', 'Xh121', 'Xh122', 'Xh123'};
elseif group == 3 %RoGator straight
    fname = {'Noracstraight81', 'Noracstraight82', 'Noracstraight83',...
        'Noracstraight121', 'Noracstraight122', 'Noracstraight123', ...
        'Noracstraight161', 'Noracstraight162', 'Noracstraight163', ...
        'RXRTstraight81', 'RXRTstraight82', 'RXRTstraight83', ...
        'RXRTstraight121', 'RXRTstraight122', 'RXRTstraight123', ...
        'RXRTstraight161', 'RXRTstraight162', 'RXRTstraight163'};
    name = {'Ns81', 'Ns82', 'Ns83', 'Ns121', 'Ns122', 'Ns123', ...
        'Ns161', 'Ns162', 'Ns163', ...
        'RXs81', 'RXs82', 'RXs83', 'RXs121', 'RXs122', 'RXs123', ...
        'RXs161', 'RXs162', 'RXs163'};
elseif group == 4 %RoGator terraces
    fname = {'Norachill61', 'Norachill62', 'Norachill63',...
        'Norachill81', 'Norachill82', 'Norachill83', ...
        'Norachill101', 'Norachill102', 'Norachill103', ...
        'RXRThill61', 'RXRThill62', 'RXRThill63', ...
        'RXRThill81', 'RXRThill82', 'RXRThill83', ...
        'RXRThill101', 'RXRThill102', 'RXRThill103', ...
        'RXRThill121', 'RXRThill122', 'RXRThill123'};   
    name = {'Nh61', 'Nh62', 'Nh63', 'Nh81', 'Nh82', 'Nh83', ...
        'Nh101', 'Nh102', 'Nh103', ...
        'RXh61', 'RXh62', 'RXh63', 'RXh81', 'RXh82', 'RXh83', ...
        'RXh101', 'RXh102', 'RXh103', 'RXh121', 'RXh122', 'RXh123'};
end

% graph labels
g1s1 = 'Sys A';  %JDR4045 system 1
g1s2 = 'Sys B'; %JDR4045 system 2
g2s1 = 'Sys C'; %RoGator system 1
g2s2 = g1s2; %RoGator system 2

% sets for use in plotting only part of a group
set1 = [1,2,3,10,11,12];
set2 = [4,5,6,13,14,15];
%set2a = [4,5,6,14];
set3 = [7,8,9,16,17,18];
set4 = [19,20,21];
set3a = [set3,set4];

%% initialize variables
nfiles = length(fname);
S = {}; % structure that holds output for group/waterway combination
taik = zeros(nfiles,1); 
validi1 = {};
ir1 = {};
ir2 = {};
ir = {};
SD = zeros(nfiles,4);
RMSD = zeros(nfiles,4);
HHI = zeros(nfiles,4);
HI = zeros(nfiles,4);
f10 = zeros(nfiles,4);
f25 = zeros(nfiles,4);
f40 = zeros(nfiles,4);

boomheightmean = zeros(nfiles,4);
distevaluated = zeros(nfiles,1);
speedevaluated = zeros(nfiles,1);
speedevaluatedkph = zeros(nfiles,1);
nptstotal = zeros(nfiles,1);
ChassisRollPositionSq = zeros(nfiles,1);

%% plots/results definition and setup
plotlatlong = 0; % figure 1, latitude vs longitude all runs
plot3figs = 0; % figures 3-5, chassis roll position and speed vs distance, 3 plots for different speeds
plotaligngraph = 0; % figure 7, chassis roll angle, speed and boom height vs distance, plotted by half
    plothalf = 1; % half to plot for figure 7
evaluatemetrics = 1; % calculate analysis metrics
qualityplot = 0; % figure 9, speed and boom height vs distance
alignchassisrollandboomheights = 0; % figure 10, speed and boom height vs unaligned distance 
plotregionanalyzed = 1; % figures 111, 113, 114, chassis roll angle, speed vs distance, latitude vs longitude 
    % these are graphs for the paper
plotboomheights = 1; % figure 13, boom heights vs distance
    % set('DefaultAxesTitleFontWeight','normal');
    % these are graphs for the paper
    
if plotlatlong == 1
    figure(1)
    clf
end

if plot3figs == 1
    figure(3)
    clf
    figure(4)
    clf
    figure(5)
    clf
end

if plotaligngraph == 1
    figure(7)
    clf
end

if qualityplot == 1
    figure(9)
    clf
end

if alignchassisrollandboomheights == 1
    figure(10)
    clf
end

if plotregionanalyzed == 1
    figure(111)
    clf
    figure(113)
    clf
    figure(114)
    clf
end

if plotboomheights == 1
    figure(13)
    clf
end


%% run analysis through all files in group
for k = 1:nfiles 
    % load file
    logname = fname{k};
    Log = eval(logname);
       
    % find distance traveled from numerical integration
    nt = length(Log.Timesec); % number of time points
    distfttimestep = zeros(nt,1);
    distfttimestep(2:end) = (Log.Timesec(2:end)-Log.Timesec(1:end-1)).*Log.Speed(2:end)*5280/3600; % distance = speed * delta t (ft)
    Log.distft = cumsum(distfttimestep); % cumulative distance (ft)
    Log.distm = Log.distft *12*2.54/100; % cumulative distance (m)

    % find turn around index as rough estimate of first/second half reference points 
    validlati = find(Log.Latitude > 43); % find valid points from latitude
    validlongi = find(Log.Longitude < -96); % find valid points from longitude
    validi1{k} = max(validlati(1),validlongi(1)); % first index where both lat and long are valid
        
    if group == 1 || group == 3
        minLat = min(Log.Latitude(validi1{k}:end));
        tai = find(Log.Latitude == minLat); % turn around index (rough estimate of separation between first and second halves)
    elseif group == 2 || group == 4
        maxLat = max(Log.Latitude(validi1{k}:end));
        tai = find(Log.Latitude == maxLat); % turn around index
    end
    tai = tai(1); % turn around index is first point if there are multiple points
    taik(k) = tai; 
 
    % find similar points to align the datasets in distance (use plotaligngraph to confirm)
    if group == 1 % JD straight
        peak1 = [556.9, 551.7, 553.9, 550.8, 555.9, 557.6, 550.9, 550.9, 557.2,...
            564.2, 558.6, 555.3, 559.7, 557.2, 545.9, 561.9, 549.5, 556.1]; % first half points
        peak2 = [921.6, 921.2, 923.7, 926.7, 928.5, 938.8, 921.4, 931.4, 931.2,...
            939.0, 926.4, 925.8, 934.1, 932.6, 918.8, 942.8, 915.6, 923.3]; % second half points      
    elseif group == 2 % JD terraces
        peak1 = [106.6, 108.5, 107.9, 102.7, 107.9, 106.5, 102.8, 103.9, 106.2,...
            104.6, 106.4, 112.7, 104.0, 104.3, 104.8, 104.8, 104.7, 106.5, 105.7, 104.8, 107.3];
        peak2 = [290.3, 293.5, 292.4, 286.2, 292.2, 292.3, 287.3, 289.1, 291.4,...
            290.2, 290.3, 298.4, 286.5, 289.7, 289.2, 288.0, 289.0, 290.1, 289.5, 288.0, 290.7];
    elseif group == 3 % RoGator straight    
        peak1 = [547.7, 558.6, 558.8, 556.2, 538.3, 554.8, 557.2, 562.9, 554.5,...
            549.0, 550.4, 562.0, 553.1, 550.2, 555.2, 547.6, 553.9, 569.1];    
        peak2 = [911.4, 924.2, 920.6, 922.8, 901.2, 917.8, 924.2, 924.3, 918.5,...
            913.9, 913.0, 924.5, 916.1, 913.4, 917.7, 911.2, 917.9, 930.8];  
    elseif group == 4 % RoGator terraces
        peak1 = [110.3, 106.6, 123.1, 107.4, 110.6, 110.8, 109.4, 112.6, 114.9,...
                112.1, 112.8, 118.2, 114.8, 114.4, 115.1, 110.1, 111.3, 111.9, 120.7, 111.6, 115.9];        
        peak2 = [293.4 289.0, 306.2, 290.0, 291.8, 292.5, 291.1, 294.4, 296.3,...
                295.6, 294.9, 301.7, 297.2, 295.4, 295.4, 293.3, 293.4, 294.5, 301.3, 291.1, 296.8];
    end
    
    % create an aligned distance
    if group == 1 || group == 3
        Log.distma1 = Log.distm + 600-peak1(k); % aligned distance first half
        Log.distma2 = Log.distm + 1000-peak2(k);% aligned distance second half
    elseif group == 2 || group == 4
        Log.distma1 = Log.distm + 120-peak1(k); 
        Log.distma2 = Log.distm + 320-peak2(k); 
    end
    
    Log.distfta1 = Log.distma1*100/(2*12*2.54);
    Log.distfta2 = Log.distma2*100/(2*12*2.54);
    
    % create new columns
    Log.ChassisRollPositionSq = Log.ChassisRollPosition.^2; 
    Log.Speedkph = Log.Speed*1.609; % speed mph to kph
    
    
    % boom heights
    % distance measured minus Z offset (in)
    Log.LO = Log.LeftWingActualGroundDistance1 - Log.LeftWingOffsetZ1; % left outside sensor
    Log.LI = Log.LeftWingActualGroundDistance2 - Log.LeftWingOffsetZ2; % left inside sensor
    Log.RI = Log.RightWingActualGroundDistance2 - Log.RightWingOffsetZ2; % right inside sensor
    Log.RO = Log.RightWingActualGroundDistance1 - Log.RightWingOffsetZ1; % right outside sensor
    % convert to cm
    Log.LOcm = Log.LO*2.54;
    Log.LIcm = Log.LI*2.54;
    Log.RIcm = Log.RI*2.54;
    Log.ROcm = Log.RO*2.54;
    
    targetheight = 40; % in
    targetheightcm = targetheight*2.54; % cm
    
    % process the analysis region using vectors of indeces
    % straight
    if group == 1 || group == 3
        if waterway100 == 0 % full straightaway
            i1start = find(Log.distma1 >= 80);  % find indicies with aligned distance >= 80 m (beginning first pass)
            i1stop  = find(Log.distma1 <= 720); % find indicies with aligned distance <= 720 m (end first pass)
            i2start = find(Log.distma2 >= 900); % find indicies with aligned distance >= 900 m (beginning second pass)
            i2stop  = find(Log.distma2 <= 1480);% find indicies with aligned distance <= 1420 m (end second pass)
        elseif waterway100 == 1 % 100 m waterway
            i1start = find(Log.distma1 >= 602-50); % top of small hill 
            i1stop  = find(Log.distma1 <= 602+50); % 100 m later
            i2start = find(Log.distma2 >= 1012-50); % 100 m earlier
            i2stop  = find(Log.distma2 <= 1012+50); % top of small hill
        end

        ir1{k} = [i1start(1):i1stop(end)]; % index range for first pass
        ir2{k} = [i2start(1):i2stop(end)]; % index range for second pass

    % terraces
    elseif group == 2 || group == 4
        i1start = find(Log.distma1 >= 21);
        i1stop  = find(Log.distma1 <= 160);
        i2start = find(Log.distma2 >= 250);
        i2stop  = find(Log.distma2 <= 430);  
        ir1{k} = [i1start(1):i1stop(end)];
        ir2{k} = [i2start(1):i2stop(end)];
    end

    ir{k} = [ir1{k}, ir2{k}]; % full index range to analyze
    npts1 = ir1{k}(end) - ir1{k}(1); % number of points first pass
    npts2 = ir2{k}(end) - ir2{k}(1); % number of points second pass
    nptstotal(k) = npts1 + npts2; % total number of points  
     
    %calculate metrics
    if evaluatemetrics == 1
        speed1 = Log.Speed(ir1{k});
        speed2 = Log.Speed(ir2{k});
        speed12 = Log.Speed(ir{k}); 
        
        heights1 = [Log.LO(ir1{k}), Log.LI(ir1{k}), Log.RI(ir1{k}), Log.RO(ir1{k})];
        heights2 = [Log.LO(ir2{k}), Log.LI(ir2{k}), Log.RI(ir2{k}), Log.RO(ir2{k})];
        heights12 = [Log.LO(ir{k}), Log.LI(ir{k}), Log.RI(ir{k}), Log.RO(ir{k})];
                
        % calculate metrics with function
        [speedevaluated1, HHI1, HI1, f101, f251, f401, SD1, RMSD1] = ...
            CalculateBoomLevelingMetrics(speed1, heights1, targetheight);
        [speedevaluated2, HHI2, HI2, f102, f252, f402, SD2, RMSD2] = ...
            CalculateBoomLevelingMetrics(speed2, heights2, targetheight);
        [speedevaluated, HHI(k,:), HI(k,:), f10(k,:), f25(k,:), f40(k,:), SD(k,:), RMSD(k,:)] = ...
            CalculateBoomLevelingMetrics(speed12, heights12, targetheight);

        distevaluated(k) = Log.distma1(ir1{k}(end)) - Log.distma1(ir1{k}(1)) + ...
             Log.distma1(ir2{k}(end)) -  Log.distma1(ir2{k}(1));
        speedevaluatedkph(k) = speedevaluated*1.609;

        ChassisRollPositionSq(k) = mean(Log.ChassisRollPositionSq(ir{k}));
        boomheightmean(k,:) = mean(heights12)*25.4;
       
        % output the analysis metrics
        analysismetricsoutput = [speedevaluatedkph, distevaluated, nptstotal, ...
            HHI(:,[1,4]), HI(:,[1,4]), f10(:,[1,4]), f25(:,[1,4]), ...
            f40(:,[1,4]), SD(:,[1,4]), RMSD(:,[1,4])];     
        % label for those metrics (rows are given by fname and abbreviated by name)
        analysismetricsoutputlabel = {'speed (kph)', 'distance (m)', ...
            'n pts total', 'HHI LO', 'HHI RO', 'HI LO', 'HI RO', ...
            'f10 LO', 'f10 RO', 'f25 LO', 'f25 RO', 'f40 LO', 'f40 RO', ...
            'SD LO (cm)', 'SD RO (cm)', 'RMSD LO (cm)', 'RMSD RO (cm)'};
    end
    
    % enter data into structures S
    S{k} = Log;
    if group == 1
        SJs{k} = S; % JD straight
    elseif group == 2
        SJh{k} = S; % JD terraces
    elseif group == 3
        SRs{k} = S; % RoGator straight
    elseif group == 4
        SRh{k} = S; % RoGator terraces 
    end

    %% plots
    % define colors
    if k < 10 % first 9 are JD/Norac
        if group == 1 || group == 2
            color = 'g-'; 
            color2 = 'g--';
            colorp = 'go';
        elseif group == 3 || group == 4
            color = 'r-';
            color2 = 'r--';
            colorp = 'ro';
        end
    else % rest are XRT
        color = 'b-';
        color2 = 'b--';
        colorp = 'bo';
    end
    
    % plot latitude/longitude
    if plotlatlong == 1
        figure(1)
        plot(Log.Longitude(validi1{k}:end),Log.Latitude(validi1{k}:end),color)
        hold on
        xlabel('longitude (deg)')
        ylabel('latitude (deg)')
    end

    % plot speed, chassis roll position per speed
    if plot3figs == 1
        if ~isempty(find(set1 == k)) % plot by set
            figure(3)
            hold on
            plot(Log.distma1(1:tai),Log.ChassisRollPosition(1:tai),'Color',[1 1 1]*200/255)
            plot(Log.distma1(1:tai),Log.Speed(1:tai),'Color',[1 1 1]*200/255)
            plot(Log.distma2(tai:end),Log.ChassisRollPosition(tai:end),'Color',[1 1 1]*200/255)
            plot(Log.distma2(tai:end),Log.Speed(tai:end),'Color',[1 1 1]*200/255)
            plot(Log.distma1(ir1{k}),Log.ChassisRollPosition(ir1{k}),color)
            plot(Log.distma1(ir1{k}),Log.Speed(ir1{k}),color)
            plot(Log.distma2(ir2{k}),Log.ChassisRollPosition(ir2{k}),color)
            plot(Log.distma2(ir2{k}),Log.Speed(ir2{k}),color) 
            grid on
            xlabel('distance (m)')
            ylabel('chassis roll position (deg), speed (mph)')
        elseif ~isempty(find(set2 == k))
            figure(4)
            hold on
            plot(Log.distma1(1:tai),Log.ChassisRollPosition(1:tai),'Color',[1 1 1]*200/255)
            plot(Log.distma1(1:tai),Log.Speed(1:tai),'Color',[1 1 1]*200/255)
            plot(Log.distma2(tai:end),Log.ChassisRollPosition(tai:end),'Color',[1 1 1]*200/255)
            plot(Log.distma2(tai:end),Log.Speed(tai:end),'Color',[1 1 1]*200/255)
            plot(Log.distma1(ir1{k}),Log.ChassisRollPosition(ir1{k}),color)
            plot(Log.distma1(ir1{k}),Log.Speed(ir1{k}),color)
            plot(Log.distma2(ir2{k}),Log.ChassisRollPosition(ir2{k}),color)
            plot(Log.distma2(ir2{k}),Log.Speed(ir2{k}),color) 
            grid on
            xlabel('distance (m)')
            ylabel('chassis roll position (deg), speed (mph)')
        elseif ~isempty(find(set3 == k)) 
            figure(5)
            hold on
            plot(Log.distma1(1:tai),Log.ChassisRollPosition(1:tai),'Color',[1 1 1]*200/255)
            plot(Log.distma1(1:tai),Log.Speed(1:tai),'Color',[1 1 1]*200/255)
            plot(Log.distma2(tai:end),Log.ChassisRollPosition(tai:end),'Color',[1 1 1]*200/255)
            plot(Log.distma2(tai:end),Log.Speed(tai:end),'Color',[1 1 1]*200/255)
            plot(Log.distma1(ir1{k}),Log.ChassisRollPosition(ir1{k}),color)
            plot(Log.distma1(ir1{k}),Log.Speed(ir1{k}),color)
            plot(Log.distma2(ir2{k}),Log.ChassisRollPosition(ir2{k}),color)
            plot(Log.distma2(ir2{k}),Log.Speed(ir2{k}),color) 
            grid on
            xlabel('distance (m)')
            ylabel('chassis roll position (deg), speed (mph)')
        end
        if group == 2 || group == 4
            if ~isempty(find(set4 == k))
            figure(5)
            plot(Log.distma1(1:tai),Log.ChassisRollPosition(1:tai),color, Log.distma1(1:tai),Log.Speed(1:tai),color)
            hold on
            plot(Log.distma2(tai:end),Log.ChassisRollPosition(tai:end),color, Log.distma2(tai:end),Log.Speed(tai:end),color)
            grid on
            xlabel('distance (m)')
            ylabel('chassis roll position (deg), speed (mph)')
            end
        end
    end
    
    % plot all in group to check alignment
    if plotaligngraph == 1
        figure(7)
        subplot(1,3,1)       
        hold on
        grid on
        if plothalf == 1
            plot(Log.distma1(1:tai),Log.ChassisRollPosition(1:tai))
            plot(Log.distma1(ir1{k}),Log.ChassisRollPosition(ir1{k}),color)
        elseif plothalf == 2
            plot(Log.distma2(tai:end),Log.ChassisRollPosition(tai:end))
            plot(Log.distma2(ir2{k}),Log.ChassisRollPosition(ir2{k}),color)
        end
        %legend()
        xlabel('distance (m)')
        ylabel('chassis roll angle (deg)')
        
        subplot(1,3,2)
        hold on
        grid on
        if plothalf == 1
            plot(Log.distma1(1:tai),Log.Speed(1:tai))
            plot(Log.distma1(ir1{k}),Log.Speed(ir1{k}),color)
        elseif plothalf == 2
            plot(Log.distma2(tai:end),Log.Speed(tai:end))
            plot(Log.distma2(ir2{k}),Log.Speed(ir2{k}),color)
        end
        %legend(name,'Orientation','vertical','Location','EastOutside')
        title(['group ',num2str(group), ', half ',num2str(plothalf)])
        xlabel('distance (m)')
        ylabel('speed (mph)')
        
        subplot(1,3,3)
        hold on
        grid on
        if plothalf == 1
            plot(Log.distma1(1:tai),Log.LO(1:tai))
            plot(Log.distma1(ir1{k}),Log.LO(ir1{k}),color)
        elseif plothalf == 2
            plot(Log.distma2(tai:end),Log.LO(tai:end))
            plot(Log.distma2(ir2{k}),Log.LO(ir2{k}),color)
        end
        legend(name,'Orientation','vertical','Location','EastOutside')
        title(['group ',num2str(group), ', half ',num2str(plothalf)])
        xlabel('distance (m)')
        ylabel('boom height (in)')     
    end
    
    % plot speed and boom heights
    if qualityplot == 1
        if ~isempty(find(set3 == k)) % plot by set
            figure(9)
            hold on
            grid on
            
            yyaxis left
            hold on
            yplot1 = S{k}.Speedkph;
            plot(S{k}.distma1(1:tai),yplot1(1:tai),'-','Color',[1 1 1]*200/255)
            plot(S{k}.distma2(tai:end),yplot1(tai:end),'-','Color',[1 1 1]*200/255)            
            plot(S{k}.distma1(ir1{k}),yplot1(ir1{k}),color)
            plot(S{k}.distma2(ir2{k}),yplot1(ir2{k}),color)
            xlabel('distance (m)')
            ylabel('speed (kph)')
            
            yyaxis right
            hold on
            yplot2 = S{k}.LOcm;
            yplot2b = S{k}.ROcm;
            plot(S{k}.distma1(1:tai),yplot2(1:tai),'-','Color',[1 1 1]*200/255)
            plot(S{k}.distma2(tai:end),yplot2(tai:end),'-','Color',[1 1 1]*200/255) 
            plot(S{k}.distma1(ir1{k}),yplot2(ir1{k}),color)
            plot(S{k}.distma2(ir2{k}),yplot2(ir2{k}),color)
            plot(S{k}.distma1(ir1{k}),yplot2b(ir1{k}),color2)
            plot(S{k}.distma2(ir2{k}),yplot2b(ir2{k}),color2)
            xlabel('distance (m)')
            ylabel('boom height (cm)')
            grid on
            yyaxis left
        end
    end
    
    % plot chassis roll and boom heights together
    if alignchassisrollandboomheights == 1
        figure(10)
        hold on
        grid on      
        yyaxis left
%         xplot1 = [SJh{k}{1}.distm; SRh{k}{1}.distm];
%         yplot1 = [SJh{k}{1}.Speed; SRh{k}{1}.Speed];        
        plot(S{k}.distm,S{k}.Speed,'-','Color',[1 1 1]*200/255)
%         plot(xplot1(ir1{k}),yplot1(ir1{k}),color)
%         plot(xplot1(ir2{k}),yplot1(ir2{k}),color)
        xlabel('unaligned distance (m)')
        ylabel('speed (mph)')

        yyaxis right
%         xplot2 = [SJh{k}{1}.distm; SRh{k}{1}.distm];
%         yplot2 = [SJh{k}{1}.RO; SRh{k}{1}.RO];
        plot(S{k}.distm,S{k}.LO,'-','Color',[1 1 1]*200/255)
%         plot(xplot2(ir1{k}),yplot2(ir1{k}),color)
%         plot(xplot2(ir2{k}),yplot2(ir2{k}),color)
        xlabel('unaligned distance (m)')
        ylabel('boom height (in)')
        grid on
        yyaxis left
    end
    
    if plotregionanalyzed == 1
        if k < 10
            lw = 2; % line weight
        else
            lw = 0.5;
        end
        
        % plot speed versus distance
        figure(111)
        hold on
        yplot1 = S{k}.Speedkph;
        h = plot(S{k}.distma1(1:tai),yplot1(1:tai),'-','Color',[1 1 1]*200/255);
        set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','off'); 
        h = plot(S{k}.distma2(tai:end),yplot1(tai:end),'-','Color',[1 1 1]*200/255);            
        set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');
        h = plot(S{k}.distma1(ir1{k}),yplot1(ir1{k}),color,'LineWidth',lw);
        set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');               
        h = plot(S{k}.distma2(ir2{k}),yplot1(ir2{k}),color,'LineWidth',lw);
        set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');            
        if k == 1 || k == 10 % legend for only the first one of JD/Norac and XRT
        set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','on');    
        end
        xlabel('distance (m)')
        ylabel('speed (km/hr)')
        grid on

%         figure(112)
%         hold on
%         yplot2 = S{k}.LIcm;
%         plot(S{k}.distma1(1:tai),yplot2(1:tai),'-','Color',[1 1 1]*200/255)
%         plot(S{k}.distma2(tai:end),yplot2(tai:end),'-','Color',[1 1 1]*200/255) 
%         plot(S{k}.distma1(ir1{k}),yplot2(ir1{k}),color)
%         plot(S{k}.distma2(ir2{k}),yplot2(ir2{k}),color)
%         xlabel('distance (m)')
%         ylabel('left outside boom height (cm)')
%         grid on
        
        % plot chassis roll angle versus distance
        figure(113)
        hold on
        yplot3 = S{k}.ChassisRollPosition;
        h = plot(S{k}.distma1(1:tai),yplot3(1:tai),'-','Color',[1 1 1]*200/255);
        set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');
        h = plot(S{k}.distma2(tai:end),yplot3(tai:end),'-','Color',[1 1 1]*200/255);
        set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');
        h = plot(S{k}.distma1(ir1{k}),yplot3(ir1{k}),color,'LineWidth',lw);
        set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');
        h = plot(S{k}.distma2(ir2{k}),yplot3(ir2{k}),color,'LineWidth',lw);
        set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');
        if k == 1 || k == 10 
        set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','on');    
        end
        xlabel('distance (m)')
        ylabel('chassis roll angle (deg)')
        grid on

        % plot longitude versus latitude
        figure(114)
        hold on
        h = plot(S{k}.Longitude(validi1{k}:tai),S{k}.Latitude(validi1{k}:tai),'-','Color',[1 1 1]*200/255);
        set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');
        h = plot(S{k}.Longitude(tai:end),S{k}.Latitude(tai:end),'-','Color',[1 1 1]*200/255); 
        set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');
        h = plot(S{k}.Longitude(ir1{k}),S{k}.Latitude(ir1{k}),color,'LineWidth',lw);
        set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');
        h = plot(S{k}.Longitude(ir2{k}),S{k}.Latitude(ir2{k}),color,'LineWidth',lw);
        set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');
        if k == 1 || k == 10
        set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','on');    
        end
        xlabel('longitude (deg)')
        ylabel('latitude (deg)')
        grid on  
    end    
    
    % plot boom heights versus distance
    if plotboomheights == 1
        setplot = set3;
        if ~isempty(find(setplot == k))
            figure(13)
            hold on
            grid on
            yplot1 = S{k}.LOcm;
            yplot2 = S{k}.ROcm;
            if k < 10
                lw = 1.5; % line weight
            else
                lw = 1.5;
            end
            % first half
            h = plot(S{k}.distma1(1:tai),yplot1(1:tai),'-','Color',[1 1 1]*200/255);
            set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');
            h = plot(S{k}.distma1(ir1{k}),yplot1(ir1{k}),color,'LineWidth',lw);
            if k == setplot(1) || k == setplot(2) || k == setplot(4) || k == setplot(5) 
            set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');
            end           
            h = plot(S{k}.distma1(ir1{k}),yplot2(ir1{k}),color2,'LineWidth',lw);
            if k == setplot(1) || k == setplot(2) || k == setplot(4) || k == setplot(5) 
            set(get(get(h,'Annotation'),'LegendInformation'),'IconDisplayStyle','off');
            end
          
            % second half
%             plot(S{k}.distma2(tai:end),yplot1(tai:end),'-','Color',[1 1 1]*200/255) 
%             plot(S{k}.distma2(ir2{k}),yplot1(ir2{k}),color)
%             plot(S{k}.distma2(ir2{k}),yplot2(ir2{k}),color2)
            xlabel('distance (m)')
            ylabel('boom height (cm)')
            grid on
            %ylim([00,5000])
            %xlim([110,160])
        end
    end
end

%% plot labeling
if plotboomheights == 1
    % labeling for plot of boom heights versus distance
    figure(13)
    h = plot(S{k}.distma1([ir1{k}(1),ir1{k}(end)]),[101, 101],'k--','LineWidth',lw);
    if group == 1 || group == 2
    legend(strcat(g1s1,' LO'), strcat(g1s1,' RO'), ...
           strcat(g1s2,' LO'), strcat(g1s2,' RO'),'target height')
    elseif group == 3 || group == 4
    legend(strcat(g2s1,' LO'), strcat(g2s1,' RO'), ...
           strcat(g2s2,' LO'), strcat(g2s2,' RO'),'target height')
    end
    if group == 1 || group == 3
        xlim([580,650])
        ylim([0,250])
    elseif group == 2 || group == 4
        xlim([110,160])
        ylim([0,500])
    end
    if group == 1
        title('R4045 boom heights over the waterway (medium terrain) at 26 km/hr')
    elseif group == 2
        title('R4045 boom heights over a terrace (rough terrain) at 16 km/hr')
    elseif group == 3
        title('RoGator boom heights over the waterway (medium terrain) at 26 km/hr')
    elseif group == 4
        title('RoGator boom heights over a terrace (rough terrain) at 16 km/hr')
    end
    set(gcf,'OuterPosition',[588, 230, 1031, 820])
    fontsize = 16;
    set(gca,'FontSize',fontsize)
end

if plotregionanalyzed == 1
    fontsize = 16;   
    % labeling for plots 
    figure(111)
    if group == 1 || group == 2
    legend(g1s1,g1s2)
    elseif group == 3 || group == 4
    legend(g2s1,g2s2)
    end
    if group == 1
        title('R4045 on straightaway')
    elseif group == 2
        title('R4045 on terraces')
    elseif group == 3
        title('RoGator on straightaway')    
    elseif group == 4
        title('RoGator on terraces')
    end
    if group == 1 || group == 3
    elseif group == 2 || group == 4
        xlim([0,600])
    end
    set(gcf,'OuterPosition',[588, 230, 1031, 820])
    set(gca,'FontSize',fontsize)
    
    figure(113)
    if group == 1 || group == 2
    legend(g1s1,g1s2)
    elseif group == 3 || group == 4
    legend(g2s1,g2s2)
    end    
    if group == 1
        title('R4045 on straightaway')
    elseif group == 2
        title('R4045 on terraces')
    elseif group == 3
        title('RoGator on straightaway')    
    elseif group == 4
        title('RoGator on terraces')
    end
    if group == 1 || group == 3
        ylim([-6,6])
    elseif group == 2 || group == 4
        xlim([0,600])
        ylim([-8,10])
    end
    set(gcf,'OuterPosition',[588, 230, 1031, 820])
    set(gca,'FontSize',fontsize)
    
    figure(114)
    if group == 1 || group == 2
    legend(g1s1,g1s2)
    elseif group == 3 || group == 4
    legend(g2s1,g2s2)
    end
    if group == 1
        title('R4045 on straightaway')
    elseif group == 2
        title('R4045 on terraces')
    elseif group == 3
        title('RoGator on straightaway')    
    elseif group == 4
        title('RoGator on terraces')
    end
    if group == 1 || group == 3
        xlim([-96.7051,-96.7048])
        ylim([43.696,43.703])
    elseif group == 2 || group == 4
        xlim([-96.709,-96.7065])
        ylim([43.6965,43.6995])
    end
    set(gcf,'OuterPosition',[588, 230, 1031, 820])
    set(gca,'FontSize',fontsize)
end

if plotlatlong == 1
    figure(1)
    hold off
    legend(name)
end

%% histograms of boom height
% organize output for histograms 
b1 = 7; %1, 4, 7 (histset1 is for JD or Norac), 1 is lowest speed, 4 is middle speed, 7 is highest speed
histset1a = [S{b1}.LOcm(ir{b1}); S{b1+1}.LOcm(ir{b1+1}); S{b1+2}.LOcm(ir{b1+2})]; % get data from 3 runs from the speed selected
histset1b = [S{b1}.ROcm(ir{b1}); S{b1+1}.ROcm(ir{b1+1}); S{b1+2}.ROcm(ir{b1+2})];
histset1 = [histset1a; histset1b]; % 1a = LO and 1b = RO

b2 = b1+9; % histset2 is for XRT (does not include maximum speed on terraces)
histset2a = [S{b2}.LOcm(ir{b2}); S{b2+1}.LOcm(ir{b2+1}); S{b2+2}.LOcm(ir{b2+2})];
histset2b = [S{b2}.ROcm(ir{b2}); S{b2+1}.ROcm(ir{b2+1}); S{b2+2}.ROcm(ir{b2+2})];
histset2 = [histset2a; histset2b]; % 2a = LO and 2b = RO
histogramdata = [histset1; histset2]; % combine into one vector
histlabel = cell(length(histogramdata),1);
if group == 1 || group == 2
    histlabel(1:length(histset1)) = {g1s1};
elseif group == 3 || group == 4
    histlabel(1:length(histset1),1) = {g2s1};
end
histlabel(length(histset1)+1:end,1) = {g1s2}; % label that accompanies histogramdata

%% structures for all runs
% put data from each run in structure
if group == 1
    SJs = S; % JD straight
    ir1Js = ir1;
elseif group == 2
    SJh = S; % JD terraces
    ir1Jh = ir1;
elseif group == 3
    SRs = S; % RoGator straight
    ir1Rs = ir1;
elseif group == 4
    SRh = S; % RoGator terraces 
    ir1Rh = ir1;
end
