function [meanspeed, HHI, HI, f10, f25, f40, SD, RMSD] = CalculateBoomLevelingMetrics(speed, heights, targetheight)
% inputs of heights, targetheight are in inches
% outputs of SD, RMSD are in cm
% outputs of HHI, HI, f10, f25, f40 are dimensionless

ndatapoints = length(speed(:,1));

%% calculate Herbst-modified Hockley Index
% buckets
HHIbuckets = [10, 25, 40, 10000]; % cm
HHIfbucketsinitial = zeros(length(HHIbuckets),size(heights,2)); % f buckets

for j = 1:length(HHIbuckets)
    lowerHHI = targetheight - HHIbuckets(j)/2.54; % lower limit (in)
    upperHHI = targetheight + HHIbuckets(j)/2.54; % lower limit (in)
    for i = 1:size(heights,2)
        HHIfbucketsinitial(j,i) = length(heights(heights(:,i)> lowerHHI & heights(:,i) < upperHHI,i))./ndatapoints;
    end
end

% remove the points that were in a closer bucket (e.g., remove f10 points from f25 calculation)
HHIfdeviationbucketsadj(1,:) = HHIfbucketsinitial(1,:); % initialize
for j=2:length(HHIbuckets)
    HHIfdeviationbucketsadj(j,:) = HHIfbucketsinitial(j,:) - HHIfbucketsinitial(j-1,:);
end
HHI = HHIfdeviationbucketsadj(1,:) + 0.75*HHIfdeviationbucketsadj(2,:) + ...
    0.25*HHIfdeviationbucketsadj(3,:) - HHIfdeviationbucketsadj(4,:);

%% calculate Hockley Index
% buckets
HIbuckets = [5, 15, 25, 10000]; % in
HIfbucketsinitial = zeros(length(HIbuckets),size(heights,2)); % f buckets
for j = 1:length(HIbuckets)
    lowerHI = targetheight - HIbuckets(j); % lower limit (in)
    upperHI = targetheight + HIbuckets(j); % lower limit (in)
    for i = 1:size(heights,2)
        HIfbucketsinitial(j,i) = length(heights(heights(:,i)> lowerHI & heights(:,i) < upperHI,i))./ndatapoints;
    end
end

% remove the points that were in a closer bucket (e.g., remove 5 in points from 15 in calculation)
HIfdeviationbucketsadj(1,:) = HIfbucketsinitial(1,:); % initialize
for j=2:length(HIbuckets)
    HIfdeviationbucketsadj(j,:) = HIfbucketsinitial(j,:) - HIfbucketsinitial(j-1,:);
end
HI = HIfdeviationbucketsadj(1,:) + 0.75*HIfdeviationbucketsadj(2,:) + ...
    0.25*HIfdeviationbucketsadj(3,:) - HIfdeviationbucketsadj(4,:);

%% calculate root mean square deviation
deviationsquared = (heights - targetheight).^2;
meandeviationsquared = mean(deviationsquared);
RMSD = sqrt(meandeviationsquared);
RMSD = RMSD*2.54; % cm

%% calculate run characteristics
meanspeed = mean(speed);
SD = std(heights)*2.54; % cm
f10 = HHIfdeviationbucketsadj(1,:);
f25 = HHIfdeviationbucketsadj(2,:);
f40 = HHIfdeviationbucketsadj(3,:);
